#include <UnitTest++.h>
#include "ShieldComponent.h"


namespace {

TEST (ShieldStartsAtInitialLevel)
{
	ShieldComponent shield(100);
	CHECK_EQUAL (100, shield.GetLevel());
}

TEST (ShieldTakesDamage)
{
	ShieldComponent shield(100);
	shield.Damage(30);
	CHECK_EQUAL (70, shield.GetLevel());
}

TEST (LevelCannotDropBelowZero)
{
	ShieldComponent shield(100);
	shield.Damage(200);
	CHECK_EQUAL (0, shield.GetLevel());
}

TEST (ShieldAbsorbsAllDamageIfPossible)
{
	ShieldComponent shield(80);
	CHECK_EQUAL (0, shield.Damage(20));
}

TEST (ShieldPassesDamageItCannotAbsorb)
{
	ShieldComponent shield(80);
	CHECK_EQUAL (20, shield.Damage(100));
}


TEST (LevelGoesUpOverTime)
{
	ShieldComponent shield(80);
	shield.Update(10.0f);
	CHECK (shield.GetLevel() > 80);
}


TEST (LevelGoesUpAtRecoveryRate)
{
	ShieldComponent shield(80);
	shield.SetRecoveryRate(10);
	shield.Update(1.0f);
	CHECK_EQUAL (90, shield.GetLevel());
}


TEST (LevelDoesNotGoUpBeyondMax)
{
	ShieldComponent shield(95);
	shield.SetRecoveryRate(10);
	shield.Update(1.0f);
	CHECK_EQUAL (ShieldComponent::kMaxLevel, shield.GetLevel());
}















/*
TEST (LevelDoesNotIncreaseRightAfterTakingDamage)
{
	ShieldComponent shield(80);
	shield.SetRecoveryRate(10);
	shield.Damage(10);	
	shield.Update(0.5f);
	CHECK_EQUAL (70, shield.GetLevel());
}

TEST (LevelIncreasesTwoSecondsAfterTakingDamage)
{
	ShieldComponent shield(80);
	shield.SetRecoveryRate(10);
	shield.Damage(10);	
	shield.Update(2.0f);
	shield.Update(0.5f);
	CHECK_EQUAL (75, shield.GetLevel());
}

TEST (LevelIncreasesUsingOnlyTheRemainingDeltaTimeFraction)
{
	ShieldComponent shield(80);
	shield.SetRecoveryRate(10);
	shield.Damage(10);	
	shield.Update(2.5f);
	CHECK_EQUAL (75, shield.GetLevel());
}
*/

}
